<?php
namespace Elementor;

class OHN_Widget extends Widget_Base {

    // CSS
    public function get_style_depends() {
        wp_enqueue_style( 'ohn-custom', plugins_url( 'assets/css/custom.css', __FILE__ ), array());
        return [
            'ohn-custom'
        ];
    }

    //JS
    public function get_script_depends() {
        
        wp_register_script( 'menuspy', plugins_url( 'assets/js/menuspy.min.js', __FILE__ ));
        wp_register_script( 'ohn-custom', plugins_url( 'assets/js/custom.js', __FILE__ ));
        
        return ['menuspy', 'ohn-custom'];
    }

    //Widget
	public function get_name() {
		return 'ohn-forms';
	}
	
	public function get_title() {
		return esc_html__('OnePage Hyperlinks Navigation', 'ohn');
	}
	
	public function get_icon() {
		return 'eicon-form-horizontal';
	}
	
	public function get_categories() {
		return [ 'modeltheme-widgets' ];
	}

   protected function register_controls() {

       $this->start_controls_section(
           'general_section',
           [
               'label' => esc_html__( 'General Settings', 'ohn' ),
               'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
           ]
       );
       $this->add_control(
           'version',
           [
               'label' => esc_html__( 'Version', 'ohn' ),
               'type' => \Elementor\Controls_Manager::SELECT,
               'default' => 'ohn-v1',
               'options' => [
                   'ohn-v1' => esc_html__( 'V1', 'ohn' ),
                   'ohn-v2' => esc_html__( 'V2', 'ohn' ),
                   'ohn-v3' => esc_html__( 'V3', 'ohn' ),
                   'ohn-v4' => esc_html__( 'V4', 'ohn' ),
               ],
           ]
       );
       $this->add_control(
           'position',
           [
               'label' => esc_html__( 'Position', 'ohn' ),
               'type' => \Elementor\Controls_Manager::SELECT,
               'default' => 'bottom-center',
               'options' => [
                   'top-left' => esc_html__( 'Top Left', 'ohn' ),
                   'top-center' => esc_html__( 'Top Center', 'ohn' ),
                   'top-right' => esc_html__( 'Top Right', 'ohn' ),
                   'middle-left' => esc_html__( 'Middle Left', 'ohn' ),
                   'middle-center' => esc_html__( 'Middle Center', 'ohn' ),
                   'middle-right' => esc_html__( 'Middle Right', 'ohn' ),
                   'bottom-left' => esc_html__( 'Bottom Left', 'ohn' ),
                   'bottom-center' => esc_html__( 'Bottom Center', 'ohn' ),
                   'bottom-right' => esc_html__( 'Bottom Right', 'ohn' ),
               ],
           ]
       );
       $this->add_control(
           'orientation',
           [
               'label' => esc_html__( 'Orientation', 'ohn' ),
               'type' => \Elementor\Controls_Manager::SELECT,
               'default' => 'ohn-horizontal',
               'options' => [
                   'ohn-horizontal' => esc_html__( 'Horizontal', 'ohn' ),
                   'ohn-vertical' => esc_html__( 'Vertical', 'ohn' ),
               ],
               'condition' => [
                   'version' => 'ohn-v1',
               ],
           ]
       );
       $this->add_control(
            'icons_mobile',
            [
               'label' => esc_html__( 'Icons Visibility', 'ohn' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'ohn-default-icons',
                'options' => [
                    'ohn-default-icons'  => esc_html__( 'All Devices', 'ohn' ),
                    'ohn-icons-desktop' => esc_html__( 'Desktop Only', 'ohn' ),
                    'ohn-icons-mobile' => esc_html__( 'Mobile Only', 'ohn' ),
                    'ohn-icons-none' => esc_html__( 'No Icons', 'ohn' ),
                ],
                'condition' => [
                   'version' => 'ohn-v1',
               ],
            ]
        );
       $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'label' => esc_html__( 'Label Typography', 'ohn' ),
                'name' => 'ohn',
                'selectors' => [
                   '{{WRAPPER}} .ohn-side-menu.ohn-v1 ul li a',
                   '{{WRAPPER}} .ohn-side-menu.ohn-v2 ul li a',
               ],
            ]
       );
       $this->add_control(
           'label_color_active_v1',
           [
               'label' => esc_html__( 'Label Color Active', 'ohn' ),
               'type' => \Elementor\Controls_Manager::COLOR,
               'selectors' => [
                   '{{WRAPPER}} .ohn-side-menu.ohn-v1 ul li.active a' => 'color: {{VALUE}}',
                   '{{WRAPPER}} .ohn-side-menu.ohn-v1 ul li.active a svg' => 'fill: {{VALUE}}',
               ],
               'condition' => [
                   'version' => 'ohn-v1',
               ],
           ]
       );
       $this->add_control(
           'bg_color_active_v1',
           [
               'label' => esc_html__( 'Background Color Active', 'ohn' ),
               'type' => \Elementor\Controls_Manager::COLOR,
               'selectors' => [
                   '{{WRAPPER}} .ohn-side-menu.ohn-v1 ul li.active' => 'background-color: {{VALUE}}',
               ],
               'condition' => [
                   'version' => 'ohn-v1',
               ],
           ]
       );
       $this->add_control(
           'label_color_active_v2',
           [
               'label' => esc_html__( 'Label Color Active', 'ohn' ),
               'type' => \Elementor\Controls_Manager::COLOR,
               'selectors' => [
                   '{{WRAPPER}} .ohn-side-menu.ohn-v2 ul li a' => 'color: {{VALUE}}',
               ],
               'condition' => [
                   'version' => 'ohn-v2',
               ],
           ]
       );
       $this->add_control(
           'border_color_v2',
           [
               'label' => esc_html__( 'Circle Border Color', 'ohn' ),
               'type' => \Elementor\Controls_Manager::COLOR,
               'selectors' => [
                    '{{WRAPPER}} .ohn-side-menu.ohn-v2 ul li a:after' => 'border-color: {{VALUE}}',
               ],
               'condition' => [
                   'version' => 'ohn-v2',
               ],
           ]
       );
       $this->add_control(
           'bg_color_active_v2',
           [
               'label' => esc_html__( 'Circle Background Color Active', 'ohn' ),
               'type' => \Elementor\Controls_Manager::COLOR,
               'selectors' => [
                   '{{WRAPPER}} .ohn-side-menu.ohn-v2 ul li.active a:after' => 'background: {{VALUE}}',
                   '{{WRAPPER}} .ohn-side-menu.ohn-v2 ul li:hover a:after' => 'background: {{VALUE}}',
               ],
               'condition' => [
                   'version' => 'ohn-v2',
               ],
           ]
       );

       $this->add_control(
           'label_color_active_v3',
           [
               'label' => esc_html__( 'Label Color Active', 'ohn' ),
               'type' => \Elementor\Controls_Manager::COLOR,
               'selectors' => [
                   '{{WRAPPER}} .ohn-side-menu.ohn-v3 ul li a span' => 'color: {{VALUE}}',
               ],
               'condition' => [
                   'version' => 'ohn-v3',
               ],
           ]
       );
       $this->add_control(
           'icon_color_v3',
           [
               'label' => esc_html__( 'Icon Color', 'ohn' ),
               'type' => \Elementor\Controls_Manager::COLOR,
               'selectors' => [
                   '{{WRAPPER}} .ohn-side-menu.ohn-v3 ul li a svg' => 'fill: {{VALUE}}',
               ],
               'condition' => [
                   'version' => 'ohn-v3',
               ],
           ]
       );
       $this->add_control(
           'bg_icon_active_v3',
           [
               'label' => esc_html__( 'Icon Color Active', 'ohn' ),
               'type' => \Elementor\Controls_Manager::COLOR,
               'selectors' => [
                   '{{WRAPPER}} .ohn-side-menu.ohn-v3 ul li.active a svg' => 'fill: {{VALUE}}',
                   '{{WRAPPER}} .ohn-side-menu.ohn-v3 ul li:hover a svg' => 'fill: {{VALUE}}',
               ],
               'condition' => [
                   'version' => 'ohn-v3',
               ],
           ]
       );
       $this->add_control(
           'bg_color_active_v3',
           [
               'label' => esc_html__( 'Background Color Active', 'ohn' ),
               'type' => \Elementor\Controls_Manager::COLOR,
               'selectors' => [
                   '{{WRAPPER}} .ohn-side-menu.ohn-v3 ul li.active a svg' => 'background: {{VALUE}}',
                   '{{WRAPPER}} .ohn-side-menu.ohn-v3 ul li:hover a svg' => 'background: {{VALUE}}',
               ],
               'condition' => [
                   'version' => 'ohn-v3',
               ],
           ]
       );
       $this->add_control(
           'label_color_v4',
           [
               'label' => esc_html__( 'Label Color', 'ohn' ),
               'type' => \Elementor\Controls_Manager::COLOR,
               'selectors' => [
                   '{{WRAPPER}} .ohn-side-menu.ohn-v4 ul li a span' => 'color: {{VALUE}}',
               ],
               'condition' => [
                   'version' => 'ohn-v4',
               ],
           ]
       );
        $this->add_control(
           'icon_active_color_v4',
           [
               'label' => esc_html__( 'Icon Active Color', 'ohn' ),
               'type' => \Elementor\Controls_Manager::COLOR,
               'selectors' => [
                   '{{WRAPPER}} .ohn-side-menu.ohn-v4 ul li.active a svg' => 'fill: {{VALUE}}',
                   '{{WRAPPER}} .ohn-side-menu.ohn-v4 ul li.active a' => 'border-left: 3px solid {{VALUE}}',
                   '{{WRAPPER}} .ohn-side-menu.ohn-v4 ul li.active a span' => 'color: {{VALUE}}',
               ],
               'condition' => [
                   'version' => 'ohn-v4',
               ],
           ]
       );
       $this->end_controls_section();
       $this->start_controls_section(
           'repeater_section',
           [
               'label' => esc_html__( 'Hyperlinks', 'ohn' ),
               'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
           ]
       );
       $repeater = new \Elementor\Repeater();
       $repeater->add_control(
           'icon',
           [
               'label' => esc_html__( 'Icon', 'ohn' ),
               'type' => \Elementor\Controls_Manager::ICONS,
               'default' => [
                   'value' => 'fas fa-circle',
                   'library' => 'fa-solid',
               ],
           ]
       );
       $repeater->add_control(
           'label',
           [
               'label' => esc_html__( 'Link Label', 'ohn' ),
               'type' => \Elementor\Controls_Manager::TEXT,
               'default' => esc_html__( 'Link Label', 'ohn' ),
               'placeholder' => esc_html__( 'Type your label here', 'ohn' ),
           ]
       );
       $repeater->add_control(
           'link_section',
           [
               'label' => esc_html__( 'Link', 'ohn' ),
               'type' => \Elementor\Controls_Manager::TEXT,
               'default' => esc_html__( 'section', 'ohn' ),
               'placeholder' => esc_html__( 'Type your section here', 'ohn' ),
           ]
       );
       $this->add_control(
           'list',
           [
               'label' => __( 'Nav Items', 'ohn' ),
               'type' => \Elementor\Controls_Manager::REPEATER,
               'fields' => $repeater->get_controls(),
               'default' => [],
               'title_field' => 'Nav Item',
           ]
       );
       $this->end_controls_section();
   }

    protected function render() {
        $settings 					= $this->get_settings_for_display();
        $version                    = $settings['version'];
        $position                   = $settings['position'];
        $orientation                = $settings['orientation'];
        $icons_mobile               = $settings['icons_mobile'];
        $label_color_active_v1      = $settings['label_color_active_v1'];
        $bg_color_active_v1         = $settings['bg_color_active_v1'];
        $label_color_active_v2      = $settings['label_color_active_v2'];
        $border_color_v2            = $settings['border_color_v2'];
        $bg_color_active_v2         = $settings['bg_color_active_v2'];
        $label_color_active_v3      = $settings['label_color_active_v3'];
        $icon_color_v3              = $settings['icon_color_v3'];
        $bg_icon_active_v3          = $settings['bg_icon_active_v3'];
        $bg_color_active_v3         = $settings['bg_color_active_v3'];
        $label_color_v4             = $settings['label_color_v4'];
        $icon_active_color_v4       = $settings['icon_active_color_v4'];
        $list                       = $settings['list'];

        $serialized_list_groups = base64_encode(serialize($list));

        $shortcode_content = '';
        $shortcode_content .= do_shortcode('[ohn-builder-shortcode 
            version="'.esc_attr($version).'"
            position="'.esc_attr($position).'"
            orientation="'.esc_attr($orientation).'"
            icons_mobile="'.esc_attr($icons_mobile).'"
            label_color_active_v1="'.esc_attr($label_color_active_v1).'"
            bg_color_active_v1="'.esc_attr($bg_color_active_v1).'"
            label_color_active_v2="'.esc_attr($label_color_active_v2).'"
            border_color_v2="'.esc_attr($border_color_v2 ).'"
            bg_color_active_v2="'.esc_attr($bg_color_active_v2).'"
            label_color_active_v3="'.esc_attr($label_color_active_v3).'"
            icon_color_v3="'.esc_attr($icon_color_v3).'"
            bg_icon_active_v3="'.esc_attr($bg_icon_active_v3).'"
            bg_color_active_v3="'.esc_attr($bg_color_active_v3).'"
            label_color_v4="'.esc_attr($label_color_v4).'"
            icon_active_color_v4="'.esc_attr($label_active_color_v4).'"
            list="'.$serialized_list_groups.'"]');

        echo  do_shortcode($shortcode_content);
    }

    protected function content_template() {

    }
}
